Монгол хэл судлал, VIII боть, Авиа зүй
Mongolian Language Studies, Volume VIII, Phonetics and Phonology

Даваажавын Уртнасан
Цэвээндоржийн Батдорж
Сангидоржийн Батхишиг

Urtnasan Davaajav
Batdorj Tseveendorj
Batkhishig Sangidorj

Улаанбаатар, 2022
Ulaanbaatar, 2022

ISBN 978-9919-504-82-3

Table: Монгол хэлний эгшгийн IPA ба жишээ
Table: Монгол хэлний гийгүүлэгчийн IPA ба жишээ
